@@ -5,7 +5,7 @@ Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
 
 import unittest
-import socket, os
+import socket, os, sys
 import Pyro4.socketutil as SU
 from Pyro4 import threadutil
 from Pyro4.socketserver.multiplexserver import SocketServer_Select, SocketServer_Poll
@@ -31,12 +31,12 @@ class TestSocketutil(unittest.TestCase):
         self.assertNotEqual("127.0.0.1", SU.getMyIpAddress("127.0.0.1",workaround127=True))
         
     def testUnusedPort(self):
-        port1=SU.findUnusedPort()
-        port2=SU.findUnusedPort()
+        port1=SU.findProbablyUnusedPort()
+        port2=SU.findProbablyUnusedPort()
         self.assertTrue(port1>0)
         self.assertNotEqual(port1,port2)
-        port1=SU.findUnusedPort(socktype=socket.SOCK_DGRAM)
-        port2=SU.findUnusedPort(socktype=socket.SOCK_DGRAM)
+        port1=SU.findProbablyUnusedPort(socktype=socket.SOCK_DGRAM)
+        port2=SU.findProbablyUnusedPort(socktype=socket.SOCK_DGRAM)
         self.assertTrue(port1>0)
         self.assertNotEqual(port1,port2)
     def testBindUnusedPort(self):
@@ -124,7 +124,15 @@ class TestSocketutil(unittest.TestCase):
         ss=SU.createBroadcastSocket((None, 0))
         port=ss.getsockname()[1]
         cs=SU.createBroadcastSocket()
-        cs.sendto(tobytes("monkey"),0,('<broadcast>',port))
+        for bcaddr in Pyro4.config.parseAddressesString(Pyro4.config.BROADCAST_ADDRS):
+            try:
+                cs.sendto(tobytes("monkey"),0,(bcaddr,port))
+            except socket.error:
+                x=sys.exc_info()[1]
+                err=getattr(x, "errno", x.args[0])
+                if err not in Pyro4.socketutil.ERRNO_EADDRNOTAVAIL:    # yeah, windows likes to throw these...
+                    if err not in Pyro4.socketutil.ERRNO_EADDRINUSE:     # and jython likes to throw thses...
+                        raise
         data,_=ss.recvfrom(500)
         self.assertEqual(tobytes("monkey"),data)
         cs.close()
@@ -185,7 +193,7 @@ class ServerCallback(object):
 class TestSocketServer(unittest.TestCase):
     def testServer_thread(self):
         daemon=ServerCallback()
-        port=SU.findUnusedPort()
+        port=SU.findProbablyUnusedPort()
         serv=SocketServer_Threadpool()
         serv.init(daemon,"localhost",port)
         self.assertEqual("localhost:"+str(port), serv.locationStr)
@@ -201,7 +209,7 @@ class TestSocketServer(unittest.TestCase):
         self.assertTrue(serv.sock is None)
     def testServer_select(self):
         daemon=ServerCallback()
-        port=SU.findUnusedPort()
+        port=SU.findProbablyUnusedPort()
         serv=SocketServer_Select()
         serv.init(daemon,"localhost",port)
         self.assertEqual("localhost:"+str(port), serv.locationStr)
@@ -217,7 +225,7 @@ class TestSocketServer(unittest.TestCase):
         self.assertTrue(serv.sock is None)
     def testServer_poll(self):
         daemon=ServerCallback()
-        port=SU.findUnusedPort()
+        port=SU.findProbablyUnusedPort()
         serv=SocketServer_Poll()
         serv.init(daemon,"localhost",port)
         self.assertEqual("localhost:"+str(port), serv.locationStr)
